package domain

import (
	"github.com/urfave/cli/v2"
)

// DomainCommand supports managing DNS entries.
var DomainCommand = &cli.Command{
	Name:      "domain",
	Usage:     "Manage domains via 3rd party providers",
	Aliases:   []string{"d"},
	ArgsUsage: "<domain>",
	Description: `
This command supports managing domain name records via 3rd party providers such
as Gandi DNS. It supports listing, creating and removing all types of records
that you might need for managing Co-op Cloud apps.

The following providers are supported:

    Gandi DNS https://www.gandi.net

You need an account with such a provider already. Typically, you need to
provide an API token on the Abra command-line when using these commands so that
you can authenticate with your provider account.

Any new provider can be integrated, we welcome change sets. See the underlying
DNS library documentation for more. It supports many existing providers and
allows to implement new provider support easily.

    https://pkg.go.dev/github.com/libdns/libdns

`,
	Subcommands: []*cli.Command{
		DomainListCommand,
		DomainCreateCommand,
		DomainRemoveCommand,
	},
}
